.. Copyright 2018-2023 Reahl Software Services (Pty) Ltd. All rights reserved.

HOWTOs
======

More advanced examples that are not covered in the :doc:`web framework tutorial <../tutorial/index>`.

Dynamic content
---------------

.. toctree::
   :maxdepth: 1

   responsivedisclosure
   paginglonglists
   refreshingwidgets
   dynamiccontenterrors

Parameterised views
-------------------

.. toctree::
   :maxdepth: 1

   programmaticparameterised
   eventresult
.. transitionstoparameterised

Concurrency
-----------
.. toctree::
   :maxdepth: 1

   optimisticlocking

Look and feel
-------------

.. toctree::
   :maxdepth: 1

   customisingerrorpages
   customisingcss
   multihomed

Charts
------

.. toctree::
   :maxdepth: 1

   plotly
   plotly2

Payments
--------

.. toctree::
   :maxdepth: 1

   paypal


Production deployment
---------------------

.. toctree::
   :maxdepth: 1

   nginx
   docker

   
Other
-----

.. toctree::
   :maxdepth: 1

   csrf
   
